@@ -25,10 +25,9 @@
 # import x2go before you import other thread based modules (e.g. paramiko)
 import x2go
 
+import sys
 import getpass
-import os,sys
 import gevent
-import paramiko
 
 # modify to your needs...
 server   = "server.mydomain.tld"
