@@ -183,7 +183,14 @@ Contact
 """
 
 __NAME__    = 'python-x2go'
-__VERSION__ = '0.4.0.9'
+__VERSION__ = '0.5.0.1'
+
+import os
+from defaults import X2GOCLIENT_OS
+
+if X2GOCLIENT_OS != 'Windows':
+    # enforce "ares" resolve in gevent (>= 1.0~)...
+    os.environ["GEVENT_RESOLVER"] = "ares"
 
 from gevent import monkey
 monkey.patch_all()
@@ -191,9 +198,9 @@ monkey.patch_all()
 import utils
 
 from client import X2GoClient
-from backends.profiles import X2GoSessionProfiles
-from backends.printing import X2GoClientPrinting
-from backends.settings import X2GoClientSettings
+from backends.profiles.file import X2GoSessionProfiles
+from backends.printing.file import X2GoClientPrinting
+from backends.settings.file import X2GoClientSettings
 from session import X2GoSession
 from sshproxy import X2GoSSHProxy
 from x2go_exceptions import *
@@ -201,12 +208,12 @@ from log import *
 
 from cleanup import x2go_cleanup
 
-from defaults import X2GOCLIENT_OS
 from defaults import CURRENT_LOCAL_USER
 from defaults import LOCAL_HOME
 from defaults import X2GO_CLIENT_ROOTDIR
 from defaults import X2GO_SESSIONS_ROOTDIR
 from defaults import X2GO_SSH_ROOTDIR
+from defaults import BACKENDS
 
 if X2GOCLIENT_OS == 'Windows':
     from xserver import X2GoClientXConfig, X2GoXServer
