@@ -38,6 +38,7 @@ PARAMIKO_FEATURE = {
     'hash-host-entries': compare_versions(PARAMIKO_VERSION, ">=", '99'),
     'host-entries-reloadable': compare_versions(PARAMIKO_VERSION, ">=", '1.11.0'),
     'preserve-known-hosts': compare_versions(PARAMIKO_VERSION, ">=", '1.11.0'),
+    'ecdsa-hostkeys': compare_versions(PARAMIKO_VERSION, ">=", '1.11.6'),
 }
 
 def _SSHClient_save_host_keys(self, filename):
@@ -116,7 +117,7 @@ def _HostKeys_add(self, hostname, keytype, key, hash_hostname=True):
 
     @param hostname: the hostname (or IP) to add
     @type hostname: str
-    @param keytype: key type (C{"ssh-rsa"} or C{"ssh-dss"})
+    @param keytype: key type (C{"ssh-rsa"}, C{"ssh-dss"} or C{"ecdsa-sha2-nistp256"})
     @type keytype: str
     @param key: the key to add
     @type key: L{PKey}
