@@ -16,9 +16,3 @@
 # along with this program; if not, write to the
 # Free Software Foundation, Inc.,
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-
-from x2go.defaults import BACKEND_CONTROLSESSION_DEFAULT
-
-from _stdout import X2GoControlSessionSTDOUT
-
-X2GoControlSession = eval(BACKEND_CONTROLSESSION_DEFAULT)
