@@ -17,12 +17,3 @@
 # Free Software Foundation, Inc.,
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
-from x2go.defaults import BACKEND_SESSIONPROFILES_DEFAULT
-
-from _file import X2GoSessionProfilesFILE
-from _winreg import X2GoSessionProfilesWINREG
-from _httpsbroker import X2GoSessionProfilesHTTPSBROKER
-from _gconf import X2GoSessionProfilesGCONF
-
-X2GoSessionProfiles = eval(BACKEND_SESSIONPROFILES_DEFAULT)
-
