@@ -18,7 +18,7 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-X2GoProxyBASE class - proxying your connection through NX3 and others.
+X2GoProxy class - proxying your connection through NX3 and others.
 
 """
 __NAME__ = 'x2goproxy-pylib'
@@ -47,12 +47,12 @@ from x2go.defaults import LOCAL_HOME as _LOCAL_HOME
 from x2go.defaults import X2GO_SESSIONS_ROOTDIR as _X2GO_SESSIONS_ROOTDIR
 
 
-class X2GoProxyBASE(threading.Thread):
+class X2GoProxy(threading.Thread):
     """\
     X2GoProxy is an abstract class for X2Go proxy connections.
 
     This class needs to be inherited from a concrete proxy class. Only 
-    currently available proxy class is: L{X2GoProxyNX3}.
+    currently available proxy class is: L{x2go.backends.proxy.nx3.X2GoProxy}.
 
     """
     PROXY_CMD = ''
@@ -69,7 +69,7 @@ class X2GoProxyBASE(threading.Thread):
     proxy = None
 
     def __init__(self, session_info=None, 
-                 ssh_transport=None, session_log="session.log", 
+                 ssh_transport=None, session_log="session.log", session_errors="session.err",
                  sessions_rootdir=os.path.join(_LOCAL_HOME, _X2GO_SESSIONS_ROOTDIR),
                  proxy_options={},
                  session_instance=None,
@@ -84,12 +84,12 @@ class X2GoProxyBASE(threading.Thread):
         @type session_log: C{str}
         @param sessions_rootdir: base dir where X2Go session files are stored (by default: ~/.x2go)
         @type sessions_rootdir: C{str}
-        @param proxy_options: a set of very C{X2GoProxy*} backend specific options; any option that is not known
-            to the C{X2GoProxy*} backend will simply be ignored
+        @param proxy_options: a set of very L{base.X2GoProxy} backend specific options; any option that is not known
+            to the L{base.X2GoProxy} backend will simply be ignored
         @type proxy_options: C{dict}
         @param logger: you can pass an L{X2GoLogger} object to the
-            L{X2GoProxy} constructor
-        @param session_instance: the L{X2GoSession} instance this C{X2GoProxy*} instance belongs to
+            L{base.X2GoProxy} constructor
+        @param session_instance: the L{X2GoSession} instance this L{base.X2GoProxy} instance belongs to
         @type session_instance: L{X2GoSession} instance
         @type logger: L{X2GoLogger} instance
         @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
@@ -108,10 +108,12 @@ class X2GoProxyBASE(threading.Thread):
         self.session_name = self.session_info.name
         self.ssh_transport = ssh_transport
         self.session_log = session_log
+        self.session_errors = session_errors
         self.proxy_options = proxy_options
         self.session_instance = session_instance
         self.PROXY_ENV = os.environ.copy()
         self.proxy = None
+        self.subsystem = 'X2Go Proxy'
 
         threading.Thread.__init__(self)
         self.daemon = True
@@ -152,8 +154,8 @@ class X2GoProxyBASE(threading.Thread):
         """
         self._keepalive = False
         # wait for thread loop to finish...
-        gevent.sleep(.5)
-        self._tidy_up()
+        while self.proxy is not None:
+            gevent.sleep(.5)
 
     def run(self):
         """\
@@ -177,7 +179,7 @@ class X2GoProxyBASE(threading.Thread):
 
         local_graphics_port = self.session_info.graphics_port
         try:
-            if self.ssh_transport.getpeername() in ('::1', '127.0.0.1', 'localhost', 'localhost.localdomain'):
+            if self.ssh_transport.getpeername()[0] in ('::1', '127.0.0.1', 'localhost', 'localhost.localdomain'):
                 local_graphics_port += 10000
         except socket.error:
             raise x2go_exceptions.X2GoControlSessionException('The control session has died unexpectedly.')
@@ -188,16 +190,15 @@ class X2GoProxyBASE(threading.Thread):
                                                       ssh_transport=self.ssh_transport,
                                                       session_instance=self.session_instance,
                                                       session_name=self.session_name,
+                                                      subsystem=self.subsystem,
                                                       logger=self.logger,
                                                      )
 
         # update the proxy port in PROXY_ARGS
         self._update_local_proxy_socket(local_graphics_port)
-        cmd_line = self._generate_cmdline()
 
         self.session_log_stdout = open('%s/%s' % (self.session_info.local_container, self.session_log, ), 'a')
         self.session_log_stderr = open('%s/%s' % (self.session_info.local_container, self.session_log, ), 'a')
-        self.logger('forking threaded subprocess: %s' % " ".join(cmd_line), loglevel=log.loglevel_DEBUG)
 
         _stdin = None
         _shell = False
@@ -208,6 +209,10 @@ class X2GoProxyBASE(threading.Thread):
         # allow inheriting classes to do something with backend specific proxy_options...
         self.process_proxy_options()
 
+        # if everything is in place, generate the command line for the subprocess call
+        cmd_line = self._generate_cmdline()
+        self.logger('forking threaded subprocess: %s' % " ".join(cmd_line), loglevel=log.loglevel_DEBUG)
+
         while not self.proxy:
             gevent.sleep(.2)
             p = self.proxy = subprocess.Popen(cmd_line,
@@ -218,7 +223,7 @@ class X2GoProxyBASE(threading.Thread):
                                               shell=_shell)
 
         while self._keepalive:
-            gevent.sleep(.2)
+            gevent.sleep(1)
 
         if _X2GOCLIENT_OS == 'Windows':
             _stdin.close()
@@ -232,6 +237,8 @@ class X2GoProxyBASE(threading.Thread):
         except WindowsError:
             pass
 
+        self._tidy_up()
+
     def process_proxy_options(self):
         """\
         Override this method to incorporate elements from C{proxy_options} 
@@ -244,7 +251,7 @@ class X2GoProxyBASE(threading.Thread):
 
             1. remove processed proxy_options from self.proxy_options
             2. once you have finished processing the proxy_options call
-            the parent class method X2GoProxyBASE.process_proxy_options()
+            the parent class method L{x2go.backends.proxy.base.X2GoProxy.process_proxy_options()}
 
         """
         # do the logging of remaining options
@@ -280,12 +287,12 @@ class X2GoProxyBASE(threading.Thread):
             # also wait for fw_tunnel to become active
             _count = 0
             _maxwait = 40
-            while (not self.fw_tunnel.is_active) and (not self.fw_tunnel.failed) and (_count < _maxwait):
+            while self.fw_tunnel and (not self.fw_tunnel.is_active) and (not self.fw_tunnel.failed) and (_count < _maxwait):
                 _count += 1
                 self.logger('waiting for port fw tunnel to come up: 0.5s x %s' % _count, loglevel=log.loglevel_DEBUG)
                 gevent.sleep(.5)
 
-        return self.proxy, bool(self.proxy) and self.fw_tunnel.is_active
+        return self.proxy, bool(self.proxy) and (self.fw_tunnel and self.fw_tunnel.is_active)
 
     def ok(self):
         """\
