@@ -160,7 +160,7 @@ class X2GoListSessionsCache(object):
             if profile_name in self.x2go_listsessions_cache.keys():
                 del self.x2go_listsessions_cache[profile_name]
             self.protected = False
-            raise x2go_exceptions.X2GoControlSessionException
+            raise x2go_exceptions.X2GoControlSessionException(str(e))
         except x2go_exceptions.X2GoTimeOutException:
             pass
         except KeyError:
@@ -184,7 +184,7 @@ class X2GoListSessionsCache(object):
             if profile_name in self.x2go_listsessions_cache.keys():
                 del self.x2go_listsessions_cache[profile_name]
             self.protected = False
-            raise x2go_exceptions.X2GoControlSessionException
+            raise x2go_exceptions.X2GoControlSessionException(str(e))
         except x2go_exceptions.X2GoTimeOutException:
             pass
         except KeyError:
@@ -206,7 +206,7 @@ class X2GoListSessionsCache(object):
             if profile_name in self.x2go_listsessions_cache.keys():
                 del self.x2go_listsessions_cache[profile_name]
             self.protected = False
-            raise x2go_exceptions.X2GoControlSessionException
+            raise x2go_exceptions.X2GoControlSessionException(str(e))
         except KeyError:
             pass
 
