@@ -63,6 +63,7 @@ if X2GOCLIENT_OS == "Windows":
     SUPPORTED_PRINTING = True
     SUPPORTED_FOLDERSHARING = True
     SUPPORTED_MIMEBOX = True
+    SUPPORTED_TELEKINESIS = False
 
 elif X2GOCLIENT_OS == "Linux":
     ROOT_DIR = '/'
@@ -74,6 +75,7 @@ elif X2GOCLIENT_OS == "Linux":
     SUPPORTED_PRINTING = True
     SUPPORTED_FOLDERSHARING = True
     SUPPORTED_MIMEBOX = True
+    SUPPORTED_TELEKINESIS = True
 
 elif X2GOCLIENT_OS == "Mac":
     ROOT_DIR = '/'
@@ -85,6 +87,7 @@ elif X2GOCLIENT_OS == "Mac":
     SUPPORTED_PRINTING = True
     SUPPORTED_FOLDERSHARING = True
     SUPPORTED_MIMEBOX = True
+    SUPPORTED_TELEKINESIS = False
 
 else:
     import exceptions
@@ -92,60 +95,51 @@ else:
     raise OSNotSupportedException('Platform %s is not supported' % platform.system())
 
 ##
-## control and terminal session backend as well as session info and proxy backend defaults
+## backends of Python X2Go
 ##
 
-BACKENDS_CONTROLSESSION = {
-    'STDOUT': 'X2GoControlSessionSTDOUT',
+BACKENDS = {
+    'X2GoControlSession': {
+        'default': 'PLAIN',
+        'PLAIN': 'x2go.backends.control.plain',
+    },
+    'X2GoTerminalSession': {
+        'default': 'PLAIN',
+        'PLAIN': 'x2go.backends.terminal.plain',
+    },
+    'X2GoServerSessionInfo': {
+        'default': 'PLAIN',
+        'PLAIN': 'x2go.backends.info.plain',
+    },
+    'X2GoServerSessionList': {
+        'default': 'PLAIN',
+        'PLAIN': 'x2go.backends.info.plain',
+    },
+    'X2GoProxy': {
+        'default': 'NX3',
+        'NX3': 'x2go.backends.proxy.nx3',
+    },
+    'X2GoSessionProfiles': {
+        'default': 'FILE',
+        'FILE': 'x2go.backends.profiles.file',
+        'GCONF': 'x2go.backends.profiles.gconf',
+        'HTTPBROKER': 'x2go.backends.profiles.httpbroker',
+        'SSHBROKER': 'x2go.backends.profiles.sshbroker',
+        'WINREG': 'x2go.backends.profiles.winreg',
+    },
+    'X2GoClientSettings': {
+        'default': 'FILE',
+        'FILE': 'x2go.backends.settings.file',
+        'GCONF': 'x2go.backends.settings.gconf',
+        'WINREG': 'x2go.backends.settings.winreg',
+    },
+    'X2GoClientPrinting': {
+        'default': 'FILE',
+        'FILE': 'x2go.backends.printing.file',
+        'GCONF': 'x2go.backends.printing.gconf',
+        'WINREG': 'x2go.backends.printing.winreg',
+    }
 }
-BACKENDS_TERMINALSESSION = {
-    'STDOUT': 'X2GoTerminalSessionSTDOUT',
-}
-BACKENDS_SERVERSESSIONINFO = {
-    'STDOUT': 'X2GoServerSessionInfoSTDOUT',
-}
-BACKENDS_SERVERSESSIONLIST = {
-    'STDOUT': 'X2GoServerSessionListSTDOUT',
-}
-BACKENDS_PROXY = {
-    'NX3': 'X2GoProxyNX3',
-}
-
-BACKEND_CONTROLSESSION_DEFAULT =  'X2GoControlSessionSTDOUT'
-BACKEND_TERMINALSESSION_DEFAULT = 'X2GoTerminalSessionSTDOUT'
-BACKEND_SERVERSESSIONINFO_DEFAULT = 'X2GoServerSessionInfoSTDOUT'
-BACKEND_SERVERSESSIONLIST_DEFAULT = 'X2GoServerSessionListSTDOUT'
-BACKEND_PROXY_DEFAULT = 'X2GoProxyNX3'
-
-##
-## profile backend defaults
-##
-
-BACKENDS_SESSIONPROFILES = {
-    'FILE': 'X2GoSessionProfilesFILE',
-    'GCONF': 'X2GoSessionProfilesGCONF',
-    'HTTPSBROKER': 'X2GoSessionProfilesHTTPSBROKER',
-    'WINREG': 'X2GoSessionProfilesWINREG',
-}
-"""Python X2Go backends for storing session profiles."""
-BACKENDS_CLIENTSETTINGS = {
-    'FILE': 'X2GoClientSettingsFILE',
-    'GCONF': 'X2GoClientSettingsGCONF',
-    'HTTPSBROKER': 'X2GoClientSettingsHTTPSBROKER',
-    'WINREG': 'X2GoClientSettingsWINREG',
-}
-"""Python X2Go backends for storing client settings."""
-BACKENDS_CLIENTPRINTING = {
-    'FILE': 'X2GoClientPrintingFILE',
-    'GCONF': 'X2GoClientPrintingGCONF',
-    'HTTPSBROKER': 'X2GoClientPrintingHTTPSBROKER',
-    'WINREG': 'X2GoClientPrintingWINREG',
-}
-"""Python X2Go backends for storing print settings."""
-
-BACKEND_SESSIONPROFILES_DEFAULT = 'X2GoSessionProfilesFILE'
-BACKEND_CLIENTSETTINGS_DEFAULT = 'X2GoClientSettingsFILE'
-BACKEND_CLIENTPRINTING_DEFAULT = 'X2GoClientPrintingFILE'
 
 ##
 ## X2Go Printing
@@ -226,7 +220,7 @@ X2GO_CLIENTPRINTING_DEFAULTS = {
         #   if open is false, the incoming print job is saved in ~/PDF folder 
         'open': True,
         # command to execute as PDF viewer
-        'command': 'xpdf',
+        'command': 'xdg-open',
     },
     'CUPS': {
         # default print queue for CUPS, if print queue does not exist, the default 
@@ -271,8 +265,8 @@ if X2GOCLIENT_OS == 'Windows':
             'display': 'localhost:40',
             'last_display': 'localhost:40',
             'process_name': 'vcxsrv.exe',
-            'test_installed': os.path.join(os.getcwd(), '..', 'pyhoca-contrib', 'mswin', 'vcxsrv-mswin', 'VcXsrv-1.14.2.0', 'vcxsrv.exe'), 
-            'run_command': os.path.join(os.getcwd(), '..', 'pyhoca-contrib', 'mswin', 'vcxsrv-mswin', 'VcXsrv-1.14.2.0', 'vcxsrv.exe'), 
+            'test_installed': os.path.join(os.getcwd(), '..', 'pyhoca-contrib', 'mswin', 'vcxsrv-mswin', 'VcXsrv-xp-1.14.3.2', 'vcxsrv.exe'), 
+            'run_command': os.path.join(os.getcwd(), '..', 'pyhoca-contrib', 'mswin', 'vcxsrv-mswin', 'VcXsrv-xp-1.14.3.2', 'vcxsrv.exe'), 
             'parameters': [':40', '-clipboard', '-multiwindow', '-notrayicon', '-nowinkill', '-nounixkill', '-swcursor', ],
         },
         'Xming': {
@@ -298,14 +292,14 @@ X2GO_SESSIONPROFILE_DEFAULTS = {
     'usesshproxy': False, 'sshproxyhost': 'proxyhost.mydomain', 'sshproxyport': 22, 'sshproxyuser': '', 'sshproxykeyfile': '',
     'sshproxytype': 'SSH', 'sshproxysameuser': False, 'sshproxysamepass': False, 'sshproxyautologin': True,
     'uniquehostkeyaliases': False,
-    'useexports': True, 'restoreexports': False, 'fstunnel': True, 'export': '',
+    'useexports': True, 'restoreexports': False, 'fstunnel': True, 'export': {},
     'usemimebox': False, 'mimeboxextensions': '', 'mimeboxaction': 'OPEN',
-    'fullscreen': False,
+    'fullscreen': False, 'clipboard': 'both',
     'width': 800,'height': 600, 'maxdim': False, 'dpi': 96, 'setdpi': False, 'xinerama': False, 'multidisp': False, 'display': 1,
     'usekbd': True, 'layout': 'us', 'type': 'pc105/us', 'variant': '',
     'sound': False, 'soundsystem': 'pulse', 'startsoundsystem': False, 'soundtunnel':True, 'defsndport':True, 'sndport':4713,
     'name': 'NEW_PROFILE', 'icon': ':icons/128x128/x2gosession.png',
-    'host': 'server.mydomain', 'user': CURRENT_LOCAL_USER, 'key': '', 'sshport': 22, 'krblogin': False, 'forwardsshagent': False,
+    'host': ['server.mydomain'], 'user': CURRENT_LOCAL_USER, 'key': '', 'sshport': 22, 'krblogin': False, 'forwardsshagent': False,
     'rootless': True, 'applications': X2GO_GENERIC_APPLICATIONS, 'command':'TERMINAL', 'published': False,
     'directrdp': False, 'directrdpsettings': '', 'rdpclient': 'rdesktop', 'rdpport': 3389,
     'rdpoptions': '-u X2GO_USER -p X2GO_PASSWORD', 'rdpserver': '',
