@@ -43,7 +43,10 @@ class X2GoFwServer(StreamServer):
     through an external proxy command launched by a C{X2GoProxy*} backend.
 
     """
-    def __init__ (self, listener, remote_host, remote_port, ssh_transport, session_instance=None, session_name=None, logger=None, loglevel=log.loglevel_DEFAULT,):
+    def __init__ (self, listener,
+                  remote_host, remote_port,
+                  ssh_transport, session_instance=None, session_name=None,
+                  subsystem=None, logger=None, loglevel=log.loglevel_DEFAULT,):
         """\
         @param listener: listen on TCP/IP socket C{(<IP>, <Port>)}
         @type listener: C{tuple}
@@ -75,18 +78,23 @@ class X2GoFwServer(StreamServer):
         self.chan = None
         self.is_active = False
         self.failed = False
-        self.keepalive = False
+        self.keepalive = None
         self.listener = listener
         self.chain_host = remote_host
         self.chain_port = remote_port
         self.ssh_transport = ssh_transport
         self.session_name = session_name
         self.session_instance = session_instance
+        self.subsystem = subsystem
 
         self.fw_socket = None
 
         StreamServer.__init__(self, self.listener, self.x2go_forward_tunnel_handle)
 
+    def start(self):
+        self.keepalive = True
+        return StreamServer.start(self)
+
     def x2go_forward_tunnel_handle(self, fw_socket, address):
         """\
         Handle for SSH/Paramiko forwarding tunnel.
@@ -106,12 +114,7 @@ class X2GoFwServer(StreamServer):
         _count = 0
         _maxwait = 20
 
-        while not _success and _count < _maxwait:
-
-            # it is recommended here to have passed on the session instance to this object...
-            if self.session_instance:
-                if not self.session_instance.is_connected():
-                    break
+        while not _success and _count < _maxwait and self.keepalive:
 
             _count += 1
             try:
@@ -121,35 +124,34 @@ class X2GoFwServer(StreamServer):
                 chan_peername = self.chan.getpeername()
                 _success = True
             except Exception, e:
-                self.logger('incoming request to %s:%d failed on attempt %d of %d: %s' % (self.chain_host,
-                                                                                          self.chain_port,
-                                                                                          _count,
-                                                                                          _maxwait,
-                                                                                          repr(e)),
-                                                                                          loglevel=log.loglevel_WARN)
+                if self.keepalive:
+                    self.logger('incoming request to %s:%d failed on attempt %d of %d: %s' % (self.chain_host,
+                                                                                              self.chain_port,
+                                                                                              _count,
+                                                                                              _maxwait,
+                                                                                              repr(e)),
+                                                                                              loglevel=log.loglevel_WARN)
                 gevent.sleep(.4)
 
         if not _success:
-            self.logger('incoming request to %s:%d failed after %d attempts' % (self.chain_host,
-                                                                                self.chain_port,
-                                                                                _count),
-                                                                                loglevel=log.loglevel_ERROR)
-            if self.session_instance:
-                self.session_instance.set_session_name(self.session_name)
-                self.session_instance.HOOK_forwarding_tunnel_setup_failed(chain_host=self.chain_host, chain_port=self.chain_port)
+            if self.keepalive:
+                self.logger('incoming request to %s:%d failed after %d attempts' % (self.chain_host,
+                                                                                    self.chain_port,
+                                                                                    _count),
+                                                                                    loglevel=log.loglevel_ERROR)
+                if self.session_instance:
+                    self.session_instance.set_session_name(self.session_name)
+                    self.session_instance.HOOK_forwarding_tunnel_setup_failed(chain_host=self.chain_host, chain_port=self.chain_port, subsystem=self.subsystem)
             self.failed = True
 
         else:
-
             self.logger('connected!  Tunnel open %r -> %r (on master connection %r -> %r)' % (
                         self.listener, (self.chain_host, self.chain_port),
                         self.fw_socket.getpeername(), chan_peername),
                         loglevel=log.loglevel_INFO)
-
             # once we are here, we can presume the tunnel to be active...
             self.is_active = True
 
-            self.keepalive = True
             try:
                 while self.keepalive:
                     r, w, x = select.select([self.fw_socket, self.chan], [], [])
@@ -168,7 +170,6 @@ class X2GoFwServer(StreamServer):
             except socket.error:
                 pass
 
-            self.is_active = False
             self.logger('Tunnel closed from %r' % (chan_peername,),
                         loglevel=log.loglevel_INFO)
 
@@ -215,6 +216,7 @@ class X2GoFwServer(StreamServer):
         Stop the forwarding tunnel.
 
         """
+        self.is_active = False
         self.close_socket()
         StreamServer.stop(self)
 
@@ -224,6 +226,7 @@ def start_forward_tunnel(local_host='127.0.0.1', local_port=22022,
                          ssh_transport=None, 
                          session_instance=None,
                          session_name=None,
+                         subsystem=None,
                          logger=None, ):
     """\
     Setup up a Paramiko/SSH port forwarding tunnel (like openssh -L option).
@@ -244,6 +247,8 @@ def start_forward_tunnel(local_host='127.0.0.1', local_port=22022,
     @type session_instance: C{obj}
     @param session_name: the session name of the X2Go session this port forwarding server belongs to
     @type session_name: C{str}
+    @param subsystem: a custom string with a component name that tries to evoke a new tunnel setup
+    @type subsystem: C{str}
     @param logger: an X2GoLogger object
     @type logger: C{obj}
 
@@ -255,6 +260,7 @@ def start_forward_tunnel(local_host='127.0.0.1', local_port=22022,
                              remote_host=remote_host, remote_port=remote_port,
                              ssh_transport=ssh_transport,
                              session_instance=session_instance, session_name=session_name,
+                             subsystem=subsystem,
                              logger=logger,
                             )
     try:
