@@ -52,13 +52,6 @@ class X2GoIniFile(object):
     always contain the same fields.
 
     """
-    defaultValues = {
-        'none': {
-            'none': 'empty', 
-            },
-        }
-    write_user_config = False
-    user_config_file = None
 
     def __init__(self, config_files, defaults=None, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
@@ -76,6 +69,9 @@ class X2GoIniFile(object):
         @type loglevel: C{int}
 
         """
+        self.user_config_file = None
+        self._write_user_config = True
+
         # make sure a None type gets turned into list type
         if not config_files:
             config_files = []
@@ -90,27 +86,30 @@ class X2GoIniFile(object):
 
         if utils._checkIniFileDefaults(defaults):
             self.defaultValues = defaults
+        else:
+            self.defaultValues = {}
 
         # we purposefully do not inherit the SafeConfigParser class
         # here as we do not want to run into name conflicts between
         # X2Go ini file options and method / property names in
         # SafeConfigParser... This is a pre-cautious approach...
-        self.iniConfig = ConfigParser.SafeConfigParser(self.defaultValues)
+        self.iniConfig = ConfigParser.SafeConfigParser()
         self.iniConfig.optionxform = str
 
         _create_file = False
         for file_name in self.config_files:
+            file_name = os.path.normpath(file_name)
             if file_name.startswith(_current_home):
                 if not os.path.exists(file_name):
                     utils.touch_file(file_name)
                     _create_file = True
+                self.user_config_file = file_name
                 break
-
         self.load()
 
         if _create_file:
-            self.write_user_config = True
-            self.write()
+            self._write_user_config = True
+            self._X2GoIniFile__write()
 
     def load(self):
         """\
@@ -195,7 +194,8 @@ class X2GoIniFile(object):
         if not self.iniConfig.has_section(section):
             self.iniConfig.add_section(section)
         self._storeValue(section, key, value)
-        self.write_user_config = True
+        self._write_user_config = True
+    __update_value = update_value
 
     def write(self):
         """\
@@ -204,20 +204,21 @@ class X2GoIniFile(object):
         For writing the first of the C{config_files} specified on instance construction
         that is writable will be used.
 
-        @return: C{True} if the user config file has been successfully writte, C{False} otherwise.
+        @return: C{True} if the user config file has been successfully written, C{False} otherwise.
         @rtype: C{bool}
 
         """
-        if self.user_config_file and self.write_user_config:
+        if self.user_config_file and self._write_user_config:
             try:
                 fd = open(self.user_config_file, 'wb')
                 self.iniConfig.write(fd)
                 fd.close()
-                self.write_user_config = False
+                self._write_user_config = False
                 return True
             except Exception, e:
                 print e
         return False
+    __write = write
 
     def get_type(self, section, key):
         """\
@@ -229,7 +230,7 @@ class X2GoIniFile(object):
         @param key: the ini file key in the given section
         @type key: C{str}
 
-        @return: a Python variable type 
+        @return: a Python variable type
         @rtype: class
 
         """
