@@ -38,11 +38,8 @@ import defaults
 import utils
 import log
 
-# we hide the default values from epydoc (that's why we transform them to _UNDERSCORE variables)
-from backends.printing import X2GoClientPrinting as _X2GoClientPrinting
-
 from defaults import X2GO_PRINTING_FILENAME as _X2GO_PRINTING_FILENAME
-
+from defaults import BACKENDS as _BACKENDS
 
 class X2GoPrintQueue(threading.Thread):
     """\
@@ -63,7 +60,7 @@ class X2GoPrintQueue(threading.Thread):
                  print_action=None,
                  print_action_args={},
                  client_instance=None,
-                 printing_backend=_X2GoClientPrinting,
+                 printing_backend=_BACKENDS['X2GoClientPrinting']['default'],
                  logger=None,
                  loglevel=log.loglevel_DEFAULT):
         """\
@@ -100,7 +97,7 @@ class X2GoPrintQueue(threading.Thread):
         if self.spool_dir: self.spool_dir = os.path.normpath(self.spool_dir)
         self.client_instance = client_instance
         self.client_rootdir = client_instance.get_client_rootdir()
-        self.printing_backend = printing_backend
+        self.printing_backend = utils._get_backend_class(printing_backend, "X2GoClientPrinting")
         if print_action is not None:
             self.set_print_action(print_action, client_instance=self.client_instance, logger=logger, **print_action_args)
         threading.Thread.__init__(self)
@@ -151,14 +148,14 @@ class X2GoPrintQueue(threading.Thread):
             job_files = [ jf for jf in l if jf.endswith('.ready') ]
             jobs = []
             for _job_file in job_files:
-                j = open(os.path.join(self.spool_dir, _job_file), 'r')
-                content = j.read()
+                _job_file_handle = open(os.path.join(self.spool_dir, _job_file), 'r')
+                content = _job_file_handle.read()
                 try:
                     (pdf_filename, job_title) = content.split('\n')[0:2]
                 except ValueError:
                     pdf_filename = content
                     job_title = 'X2Go Print Job'
-                j.close()
+                _job_file_handle.close()
                 jobs.append((_job_file, pdf_filename, job_title))
             return [ j for j in jobs if j[1] not in self.active_jobs.keys() ]
         else:
