@@ -35,6 +35,7 @@ if _X2GOCLIENT_OS == 'Windows':
 
 # modules
 import os
+import sys
 import threading
 import gevent
 import copy
@@ -99,10 +100,27 @@ class X2GoPulseAudio(threading.Thread):
         cmd_options = [
             '-n',
             '--exit-idle-time=-1',
-            '-L "module-native-protocol-tcp port=4713"',
+            '-L "module-native-protocol-tcp port=4713 auth-cookie=\\\\.pulse-cookie"',
             '-L "module-esound-protocol-tcp port=16001"',
             '-L module-waveout',
         ]
+
+        # Fix for python-x2go bug #537.
+        # Works Around PulseAudio bug #80772.
+        # Tested with PulseAudio 5.0.
+        # This argument will not cause PulseAudio 1.1 to fail to launch.
+        # However, PulseAudio 1.1 ignores it for some reason.
+        # So yes, the fact that 1.1 ignores it would be a bug in python-x2go if
+        # we ever ship 1.1 again.
+        #
+        # wv.major == 5 matches 2000, XP, and Server 2003 (R2).
+        # (Not that we support 2000.)
+        wv = sys.getwindowsversion()
+        if (wv.major==5):
+            self.logger('Windows XP or Server 2003 (R2) detected.', loglevel=log.loglevel_DEBUG)
+            self.logger('Setting PulseAudio to "Normal" CPU priority.', loglevel=log.loglevel_DEBUG)
+            cmd_options.insert(0,"--high-priority=no")
+
         cmd_options = " %s" % " ".join(cmd_options)
 
         if not os.path.isdir(os.path.join(_LOCAL_HOME, '.pulse', '%s-runtime' % socket.gethostname())):
