@@ -36,21 +36,15 @@ import utils
 import session
 import x2go_exceptions
 
-# import the default terminal session backend
-from x2go.backends.control import X2GoControlSession as _X2GoControlSession
-from x2go.backends.terminal import X2GoTerminalSession as _X2GoTerminalSession
-from x2go.backends.info import X2GoServerSessionInfo as _X2GoServerSessionInfo
-from x2go.backends.info import X2GoServerSessionList as _X2GoServerSessionList
-from x2go.backends.proxy import X2GoProxy as _X2GoProxy
-from x2go.backends.settings import X2GoClientSettings as _X2GoClientSettings
-from x2go.backends.printing import X2GoClientPrinting as _X2GoClientPrinting
-
 from defaults import LOCAL_HOME as _LOCAL_HOME
 from defaults import X2GO_CLIENT_ROOTDIR as _X2GO_CLIENT_ROOTDIR
 from defaults import X2GO_SESSIONS_ROOTDIR as _X2GO_SESSIONS_ROOTDIR
 from defaults import X2GO_SESSIONPROFILE_DEFAULTS as _X2GO_SESSIONPROFILE_DEFAULTS
 from defaults import X2GO_SSH_ROOTDIR as _X2GO_SSH_ROOTDIR
 
+from defaults import BACKENDS as _BACKENDS
+
+
 class X2GoSessionRegistry(object):
     """\
     This class is utilized by L{X2GoClient} instances to maintain a good overview on
@@ -462,13 +456,13 @@ class X2GoSessionRegistry(object):
 
     def register(self, server, profile_id, profile_name,
                  session_name=None,
-                 control_backend=_X2GoControlSession,
-                 terminal_backend=_X2GoTerminalSession,
-                 info_backend=_X2GoServerSessionInfo,
-                 list_backend=_X2GoServerSessionList,
-                 proxy_backend=_X2GoProxy,
-                 settings_backend=_X2GoClientSettings,
-                 printing_backend=_X2GoClientPrinting,
+                 control_backend=_BACKENDS['X2GoControlSession']['default'],
+                 terminal_backend=_BACKENDS['X2GoTerminalSession']['default'],
+                 info_backend=_BACKENDS['X2GoServerSessionInfo']['default'],
+                 list_backend=_BACKENDS['X2GoServerSessionList']['default'],
+                 proxy_backend=_BACKENDS['X2GoProxy']['default'],
+                 settings_backend=_BACKENDS['X2GoClientSettings']['default'],
+                 printing_backend=_BACKENDS['X2GoClientPrinting']['default'],
                  client_rootdir=os.path.join(_LOCAL_HOME,_X2GO_CLIENT_ROOTDIR),
                  sessions_rootdir=os.path.join(_LOCAL_HOME,_X2GO_SESSIONS_ROOTDIR),
                  ssh_rootdir=os.path.join(_LOCAL_HOME,_X2GO_SSH_ROOTDIR),
@@ -488,26 +482,26 @@ class X2GoSessionRegistry(object):
         @param session_name: session name (if available)
         @type session_name: C{str}
         @param control_backend: X2Go control session backend to use
-        @type control_backend: C{class}
+        @type control_backend: C{str}
         @param terminal_backend: X2Go terminal session backend to use
-        @type terminal_backend: C{class}
+        @type terminal_backend: C{str}
         @param info_backend: X2Go session info backend to use
-        @type info_backend: C{class}
+        @type info_backend: C{str}
         @param list_backend: X2Go session list backend to use
-        @type list_backend: C{class}
+        @type list_backend: C{str}
         @param proxy_backend: X2Go proxy backend to use
-        @type proxy_backend: C{class}
+        @type proxy_backend: C{str}
         @param settings_backend: X2Go client settings backend to use
-        @type settings_backend: C{class}
+        @type settings_backend: C{str}
         @param printing_backend: X2Go client printing backend to use
-        @type printing_backend: C{class}
+        @type printing_backend: C{str}
         @param client_rootdir: client base dir (default: ~/.x2goclient)
         @type client_rootdir: C{str}
         @param sessions_rootdir: sessions base dir (default: ~/.x2go)
         @type sessions_rootdir: C{str}
         @param ssh_rootdir: ssh base dir (default: ~/.ssh)
         @type ssh_rootdir: C{str}
-        @param keep_controlsession_alive: On last L{X2GoSession.disconnect()} keep the associated C{X2GoControlSession*} instance alive?
+        @param keep_controlsession_alive: On last L{X2GoSession.disconnect()} keep the associated C{X2GoControlSession} instance alive?
         @ŧype keep_controlsession_alive: C{bool}
         @param add_to_known_hosts: Auto-accept server host validity?
         @type add_to_known_hosts: C{bool}
@@ -539,6 +533,12 @@ class X2GoSessionRegistry(object):
             if _k in kwargs.keys():
                 _params[_k] = kwargs[_k]
 
+        # allow injection of PKey objects (Paramiko's private SSH keys)
+        if kwargs.has_key('pkey'):
+            _params['pkey'] = kwargs['pkey']
+        if kwargs.has_key('sshproxy_pkey'):
+            _params['sshproxy_pkey'] = kwargs['sshproxy_pkey']
+
         # when starting a new session, we will try to use unused registered virgin sessions
         # depending on your application layout, there should either be one or no such virgin session at all
         _virgin_sessions = [ s for s in self.virgin_sessions_of_profile_name(profile_name, return_objects=True) if not s.activated ]
@@ -659,21 +659,21 @@ class X2GoSessionRegistry(object):
             sessions = [ ts for ts in self.registry.values() if eval('ts.%s' % state) ]
         if return_profile_names:
             profile_names = []
-            for session in sessions:
-                if session.profile_name not in profile_names:
-                    profile_names.append(session.profile_name)
+            for this_session in sessions:
+                if this_session.profile_name and this_session.profile_name not in profile_names:
+                    profile_names.append(this_session.profile_name)
             return profile_names
         elif return_profile_ids:
             profile_ids = []
-            for session in sessions:
-                if session.profile_id not in profile_ids:
-                    profile_ids.append(session.profile_id)
+            for this_session in sessions:
+                if this_session.profile_id and this_session.profile_id not in profile_ids:
+                    profile_ids.append(this_session.profile_id)
             return profile_ids
         elif return_session_names:
             session_names = []
-            for session in sessions:
-                if session.session_name not in session_names:
-                    session_names.append(session.session_name)
+            for this_session in sessions:
+                if this_session.session_name and this_session.session_name not in session_names:
+                    session_names.append(this_session.session_name)
             return session_names
         elif return_objects:
             return sessions
