@@ -170,7 +170,7 @@ class X2GoRevFwTunnel(threading.Thread):
         """
         if self._accept_channels == False:
             self._accept_channels = True
-            self._requested_port = self.ssh_transport.request_port_forward('', self.server_port, handler=x2go_transport_tcp_handler)
+            self._requested_port = self.ssh_transport.request_port_forward('127.0.0.1', self.server_port, handler=x2go_transport_tcp_handler)
             self.logger('resumed thread: %s' % repr(self), loglevel=log.loglevel_DEBUG)
 
     def notify(self):
@@ -202,14 +202,14 @@ class X2GoRevFwTunnel(threading.Thread):
 
     def _request_port_forwarding(self):
         try:
-            self._requested_port = self.ssh_transport.request_port_forward('', self.server_port, handler=x2go_transport_tcp_handler)
+            self._requested_port = self.ssh_transport.request_port_forward('127.0.0.1', self.server_port, handler=x2go_transport_tcp_handler)
         except paramiko.SSHException:
             # if port forward request fails, we try to tell the server to cancel all foregoing port forward requests on 
             # self.server_port
             self.cancel_port_forward('', self.server_port)
             gevent.sleep(1)
             try:
-                self._requested_port = self.ssh_transport.request_port_forward('', self.server_port, handler=x2go_transport_tcp_handler)
+                self._requested_port = self.ssh_transport.request_port_forward('127.0.0.1', self.server_port, handler=x2go_transport_tcp_handler)
             except paramiko.SSHException, e:
                 if self.session_instance:
                     self.session_instance.HOOK_rforward_request_denied(server_port=self.server_port)
@@ -314,16 +314,19 @@ def x2go_rev_forward_channel_handler(chan=None, addr='', port=0, parent_thread=N
                                                               loglevel=log.loglevel_INFO)
     while parent_thread._accept_channels:
         r, w, x = select.select([fw_socket, chan], [], [])
-        if fw_socket in r:
-            data = fw_socket.recv(1024)
-            if len(data) == 0:
-                break
-            chan.send(data)
-        if chan in r:
-            data = chan.recv(1024)
-            if len(data) == 0:
-                break
-            fw_socket.send(data)
+        try:
+            if fw_socket in r:
+                data = fw_socket.recv(1024)
+                if len(data) == 0:
+                    break
+                chan.send(data)
+            if chan in r:
+                data = chan.recv(1024)
+                if len(data) == 0:
+                    break
+                fw_socket.send(data)
+        except socket.error, e:
+            logger('Reverse tunnel %s encoutered socket error: %s' % (chan, str(e)), loglevel=log.loglevel_WARN)
 
     chan.close()
     fw_socket.close()
