@@ -107,12 +107,12 @@ class _SSHServer(paramiko.ServerInterface):
         @rtype: C{int}
 
         """
+        self.logger('sFTP server %s: username is %s' % (self, self.current_local_user), loglevel=log.loglevel_DEBUG)
         if username == self.current_local_user:
-            self.logger('sFTP server %s: username is %s' % (self, self.current_local_user), loglevel=log.loglevel_DEBUG)
             if type(key) == paramiko.RSAKey and key == self.auth_key:
-                self.logger('sFTP server %s: publickey auth has been successful' % (self), loglevel=log.loglevel_INFO)
+                self.logger('sFTP server %s: publickey auth (type: %s) has been successful' % (self, key.get_name()), loglevel=log.loglevel_INFO)
                 return paramiko.AUTH_SUCCESSFUL
-        self.logger('sFTP server %s: publickey auth failed' % (self), loglevel=log.loglevel_WARN)
+        self.logger('sFTP server %s: publickey (type: %s) auth failed' % (self, key.get_name()), loglevel=log.loglevel_WARN)
         return paramiko.AUTH_FAILED
 
     def get_allowed_auths(self, username):
