@@ -150,6 +150,10 @@ class X2GoSSHProxy(paramiko.SSHClient, threading.Thread):
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
 
+        if hostname and hostname in (types.UnicodeType, types.StringType):
+            hostname = [hostname]
+        if hostname and hostname in (types.ListType, types.TupleType):
+            hostname = random.choice(list(hostname))
         self.hostname, self.port, self.username = hostname, port, username
 
         if sshproxy_port: self.port = sshproxy_port
@@ -157,6 +161,10 @@ class X2GoSSHProxy(paramiko.SSHClient, threading.Thread):
         # translate between X2GoSession options and paramiko.SSHCLient.connect() options
         # if <hostname>:<port> is used for sshproxy_host, then this <port> is used
         if sshproxy_host:
+            if sshproxy_host and type(sshproxy_host) in (types.UnicodeType, types.StringType):
+                sshproxy_host = [sshproxy_host]
+            if type(sshproxy_host) in (types.ListType, types.TupleType):
+                sshproxy_host = random.choice(list(sshproxy_host))
             if sshproxy_host.find(':'):
                 self.hostname = sshproxy_host.split(':')[0]
                 try: self.port = int(sshproxy_host.split(':')[1])
@@ -177,9 +185,18 @@ class X2GoSSHProxy(paramiko.SSHClient, threading.Thread):
             self.local_port = int(self.local_port)
             self.remote_port = int(self.remote_port)
         else:
+            if local_host and type(local_host) in (types.UnicodeType, types.StringType):
+                local_host = [local_host]
+            if local_host and type(local_host) in (types.ListType, types.TupleType):
+                local_host = random.choice(list(local_host))
+            if remote_host and type(remote_host) in (types.UnicodeType, types.StringType):
+                remote_host = [remote_host]
+            if remote_host and type(remote_host) in (types.ListType, types.TupleType):
+                remote_host = random.choice(remote_host)
+            print "LOCAL_HOST: ", local_host
             self.local_host = local_host
             self.local_port = int(local_port)
-            self.remote_host = remote_host
+            self.remote_host =  remote_host
             self.remote_port = int(remote_port)
 
         # allow more trailing whitespace tolerance in hostnames
@@ -331,7 +348,7 @@ class X2GoSSHProxy(paramiko.SSHClient, threading.Thread):
                 # since Paramiko 1.7.7.1 there is compression available, let's use it if present...
                 t = self.get_transport()
                 if x2go._paramiko.PARAMIKO_FEATURE['use-compression']:
-                    t.use_compression(compress=True)
+                    t.use_compression(compress=False)
                 t.set_keepalive(5)
 
             # if there is no private key, we will use the given password, if any
@@ -391,15 +408,6 @@ class X2GoSSHProxy(paramiko.SSHClient, threading.Thread):
         """
         if self.get_transport() is not None and self.get_transport().is_authenticated():
             self.local_port = utils.detect_unused_port(bind_address=self.local_host, preferred_port=self.local_port)
-            if self.client_instance is not None:
-                _profile_id = self.session_instance.get_profile_id()
-                if self.client_instance.session_profiles.has_profile(_profile_id):
-                    self.client_instance.session_profiles.update_value(_profile_id,
-                                                                       'sshproxytunnel',
-                                                                       '%s:%s:%s:%s' % (self.local_host, self.local_port, self.remote_host, self.remote_port)
-                                                                      )
-                self.client_instance.session_profiles.write_user_config = True
-                self.client_instance.session_profiles.write()
             self.fw_tunnel = forward.start_forward_tunnel(local_host=self.local_host,
                                                           local_port=self.local_port,
                                                           remote_host=self.remote_host,
