@@ -34,6 +34,7 @@ import gevent
 import string
 import subprocess
 import distutils.version
+import paramiko
 
 # Python X2Go modules
 from defaults import X2GOCLIENT_OS as _X2GOCLIENT_OS
@@ -41,6 +42,10 @@ from defaults import X2GO_SESSIONPROFILE_DEFAULTS as _X2GO_SESSIONPROFILE_DEFAUL
 from defaults import X2GO_MIMEBOX_ACTIONS as _X2GO_MIMEBOX_ACTIONS
 from defaults import pack_methods_nx3
 
+from defaults import BACKENDS as _BACKENDS
+
+import x2go_exceptions
+
 if _X2GOCLIENT_OS != 'Windows':
     import Xlib
     from defaults import X_DISPLAY as _X_DISPLAY
@@ -270,18 +275,27 @@ def _convert_SessionProfileOptions_2_SessionParams(options):
 
         _export = _params['export']
         del _params['export']
-        # fix for wrong export field usage in PyHoca-GUI/CLI and python-x2go before 20110923
-        _export = _export.replace(",", ";")
+        if type(_export) is types.DictType:
 
-        _export = _export.strip().strip('"').strip().strip(';').strip()
-        _export_list = [ f for f in _export.split(';') if f ]
+            # since Python X2Go 0.5.0.0
+            _params['share_local_folders'] = _export.keys()
+
+        else:
+
+            # before Python X2Go 0.5.0.0 (analysing the INI file's format for the export field)
 
-        _params['share_local_folders'] = []
-        for _shared_folder in _export_list:
             # fix for wrong export field usage in PyHoca-GUI/CLI and python-x2go before 20110923
-            if not ":" in _shared_folder: _shared_folder = "%s:1" % _shared_folder
-            if _shared_folder.split(":")[-1] == "1":
-                _params['share_local_folders'].append(":".join(_shared_folder.split(":")[:-1]))
+            _export = _export.replace(",", ";")
+
+            _export = _export.strip().strip('"').strip().strip(';').strip()
+            _export_list = [ f for f in _export.split(';') if f ]
+
+            _params['share_local_folders'] = []
+            for _shared_folder in _export_list:
+                # fix for wrong export field usage in PyHoca-GUI/CLI and python-x2go before 20110923
+                if not ":" in _shared_folder: _shared_folder = "%s:1" % _shared_folder
+                if _shared_folder.split(":")[-1] == "1":
+                    _params['share_local_folders'].append(":".join(_shared_folder.split(":")[:-1]))
 
     if options['fullscreen']:
         _params['geometry'] = 'fullscreen'
@@ -339,8 +353,6 @@ def _convert_SessionProfileOptions_2_SessionParams(options):
             try: del _params['sshproxytunnel']
             except KeyError: pass
 
-        _params['sshproxy_tunnel'] = 'localhost:44444:%s:%s' % (_params['server'], _params['port'])
-
 
     # currently known but ignored in Python X2Go
     _ignored_options = [
@@ -560,6 +572,7 @@ def local_color_depth():
         dc = win32gui.GetDC(None)
         _depth = win32print.GetDeviceCaps(dc, win32con.BITSPIXEL) * win32print.GetDeviceCaps(dc, win32con.PLANES)
         win32gui.ReleaseDC(None, dc)
+        return _depth
 
 def is_color_depth_ok(depth_session, depth_local):
     """\
@@ -600,30 +613,31 @@ def find_session_window(session_name):
     if _X2GOCLIENT_OS != 'Windows':
         # establish connection to the win API in use...
         display = _X_DISPLAY
-        root = display.screen().root
+        if display:
+            root = display.screen().root
 
-        success = False
-        windowIDs_obj = root.get_full_property(display.intern_atom('_NET_CLIENT_LIST'), Xlib.X.AnyPropertyType)
+            success = False
+            windowIDs_obj = root.get_full_property(display.intern_atom('_NET_CLIENT_LIST'), Xlib.X.AnyPropertyType)
 
-        if windowIDs_obj is None:
-            # works with i3 session manager...
-            windowIDs_obj = root.get_full_property(display.intern_atom('_NET_CLIENT_LIST_STACKING'), Xlib.X.AnyPropertyType)
+            if windowIDs_obj is None:
+                # works with i3 session manager...
+                windowIDs_obj = root.get_full_property(display.intern_atom('_NET_CLIENT_LIST_STACKING'), Xlib.X.AnyPropertyType)
 
-        if windowIDs_obj is not None:
-            windowIDs = windowIDs_obj.value
+            if windowIDs_obj is not None:
+                windowIDs = windowIDs_obj.value
 
-            for windowID in windowIDs:
-                window = display.create_resource_object('window', windowID)
-                try:
-                    name = window.get_wm_name()
-                except Xlib.error.BadWindow:
-                    continue
-                if name is not None and session_name in name:
-                    success = True
-                    break
+                for windowID in windowIDs:
+                    window = display.create_resource_object('window', windowID)
+                    try:
+                        name = window.get_wm_name()
+                    except Xlib.error.BadWindow:
+                        continue
+                    if name is not None and "X2GO-{session_name}".format(session_name=session_name) == name:
+                        success = True
+                        break
 
-        if success:
-            return window
+            if success:
+                return window
 
     else:
 
@@ -642,22 +656,17 @@ def find_session_window(session_name):
 
 def get_desktop_geometry():
     """\
-    Get the geometry of the current screen's desktop by
-    wrapping around::
-
-        xprop -root '_NET_DESKTOP_GEOMETRY'
+    Get the geometry of the current screen's desktop.
 
     @return: a (<width>, <height>) tuple will be returned
     @rtype: C{tuple}
 
     """
     if _X2GOCLIENT_OS != 'Windows':
-        p = subprocess.Popen(['xprop', '-root', '_NET_DESKTOP_GEOMETRY',], stdout=subprocess.PIPE, )
-        _paramval = p.stdout.read().split("=")
-        if len(_paramval) == 2:
-            _list = _paramval[1].rstrip('\n').split(',')
-            if len(_list) == 2:
-                return (_list[0].strip(), _list[1].strip())
+        display = _X_DISPLAY
+        if display:
+            root = display.screen().root
+            return (root.get_geometry().width, root.get_geometry().height)
 
     return None
 
@@ -819,3 +828,75 @@ class ProgressStatus(object):
             return self.status
         else:
             raise StopIteration
+
+def _get_backend_class(backend, class_name):
+    # silence pyflakes, the _this_class var will be assigned in an exec() statement below...
+    _this_class = None
+    if type(backend) not in (types.StringType, types.UnicodeType): return backend
+    backend = backend.upper()
+    available_backends = [ k for k in _BACKENDS[class_name].keys() if k != 'default' ]
+    # if for backend is given 'default' use the default backend module
+    if backend == 'default': backend = _BACKENDS[class_name]['default']
+    if backend in available_backends:
+        exec("from {backend} import {class_name} as _this_class".format(backend=_BACKENDS[class_name][backend], class_name=class_name))
+    else:
+        raise x2go_exceptions.X2GoBackendException('unknown backend name %s for class %s' % (backend, class_name))
+    return _this_class
+
+def genkeypair(local_username, client_address, key_type='RSA'):
+    """\
+    Generate an SSH pub/priv key pair without writing the private key to file.
+
+    @param local_username: the key is for this user
+    @type local_username: C{unicode}
+    @param client_address: the key is only valid for this client
+    @type client_address: C{unicode}
+    @param key_type: either of: RSA, DSA
+    @type key_type: C{unicode}
+
+    """
+    key = None
+    pubkey = None
+
+    # generate key pair
+    if unicode(key_type) == u'RSA':
+        key = paramiko.RSAKey.generate(2048)
+    elif unicode(key_type) == u'DSA':
+        key = paramiko.DSSKey.generate(1024)
+
+    if key:
+
+        # assemble the public key
+        if key_type == "RSA":
+            pubkey_type = 'ssh-rsa'
+        elif key_type == "DSA":
+            pubkey_type = 'ssh-dss'
+
+        # FIXME: the from option does not work properly by some reason. Fix it later
+        #pubkey = "from={client_address},no-X11-forwarding,no-pty,no-user-rc {pubkey_type} {pubkey} {local_username}@{client_address}".format(pubkey=key.get_base64(), pubkey_type=pubkey_type, local_username=local_username, client_address=client_address)
+        pubkey = "no-X11-forwarding,no-pty,no-user-rc {pubkey_type} {pubkey} {local_username}@{client_address}".format(pubkey=key.get_base64(), pubkey_type=pubkey_type, local_username=local_username, client_address=client_address)
+
+    return (pubkey, key)
+
+
+def which(basename):
+    """\
+    Python equivalent to the shell command "which".
+
+    @param basename: the basename of an application to be search for in $PATH
+    @type basename: C{str}
+
+    @return: full path to the application
+    @rtype: C{str}
+
+    """
+    if _X2GOCLIENT_OS == 'Windows':
+        delim = ";"
+    else:
+        delim = ":"
+
+    for path in os.environ["PATH"].split(delim):
+        if os.path.exists(os.path.join(path, basename)):
+                return os.path.join(path, basename)
+
+    return None
