@@ -67,8 +67,9 @@ class X2GoSSHProxyException(_X2GoException): pass
 class X2GoSSHProxyAuthenticationException(_X2GoException): pass
 class X2GoNotImplementedYetException(_X2GoException): pass
 class X2GoDesktopSharingDenied(_X2GoException): pass
-class X2GoDesktopSharingDenied(_X2GoException): pass
 class X2GoTimeOutException(_X2GoException): pass
+class X2GoBrokerConnectionException(_X2GoException): pass
+class X2GoTelekinesisClientException(_X2GoException): pass
 if _X2GOCLIENT_OS != 'Windows':
     # faking Windows errors on non-Windows systems...
     class WindowsError(_X2GoException): pass
@@ -100,3 +101,4 @@ class X2goSSHProxyAuthenticationException(_X2GoException): pass
 class X2goNotImplementedYetException(_X2GoException): pass
 class X2goDesktopSharingException(_X2GoException): pass
 class X2goTimeOutException(_X2GoException): pass
+
