@@ -50,9 +50,8 @@ class X2GoClientXConfig(inifiles.X2GoIniFile):
     This class is needed for Windows systems and (maybe soon) for Unix desktops using Wayland.
 
     """
-    defaultValues = _X2GO_CLIENTXCONFIG_DEFAULTS
 
-    def __init__(self, config_files=_X2GO_XCONFIG_CONFIGFILES, defaults=None, logger=None, loglevel=log.loglevel_DEFAULT):
+    def __init__(self, config_files=_X2GO_XCONFIG_CONFIGFILES, defaults=_X2GO_CLIENTXCONFIG_DEFAULTS, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
         Constructs an L{X2GoClientXConfig} instance. This is normally done by an L{X2GoClient} instance.
         You can retrieve this L{X2GoClientXConfig} instance with the C{X2GoClient.get_client_xconfig()} 
@@ -92,6 +91,20 @@ class X2GoClientXConfig(inifiles.X2GoIniFile):
             self.write_user_config = True
             self.write()
 
+    def write(self):
+        """\
+        Store the Xserver configuration to the storage backend (i.e. on disk).
+
+        For writing the first of the C{config_files} specified on instance construction
+        that is writable will be used.
+
+        @return: C{True} if the user config file has been successfully written, C{False} otherwise.
+        @rtype: C{bool}
+
+        """
+        self._write_user_config = self.write_user_config
+        return self._X2GoIniFile__write()
+
     def get_xserver_config(self, xserver_name):
         """\
         Retrieve the XServer configuration (from the xconfig file) for the given XServer application.
@@ -140,13 +153,12 @@ class X2GoClientXConfig(inifiles.X2GoIniFile):
         """
         _running = []
         _wmi = wmi.WMI()
-        _p_names = []
-        for process in _wmi.Win32_Process():
-            _p_names.append(process.Name)
+        _my_wmi_sessionid = [ _p.SessionId for _p in _wmi.Win32_Process() if _p.ProcessId == os.getpid() ][0]
 
+        _process_list = _wmi.Win32_Process()
         for xserver_name in self.installed_xservers:
             process_name = self.get_xserver_config(xserver_name)['process_name']
-            if process_name in _p_names:
+            if [ _p.Name for _p in _process_list if _p.Name == process_name and _p.SessionId == _my_wmi_sessionid ]:
                 # XServer is already running
                 _running.append(xserver_name)
                 continue
@@ -220,20 +232,26 @@ class X2GoClientXConfig(inifiles.X2GoIniFile):
             # otherwise use a detection algorithm to find a free TCP/IP port
             else:
                 _xserver_port = _default_xserver_port +1
+                self.logger('Attempting to detect an unused TCP/IP port for our X-Server, starting with port %s' % _xserver_port, loglevel=log.loglevel_DEBUG)
                 while utils.detect_unused_port(preferred_port=_xserver_port) != _xserver_port:
-                        _xserver_port += 1
+                    _xserver_port += 1
+                    self.logger('TCP/IP port was in use, trying next port: %s' % _xserver_port, loglevel=log.loglevel_DEBUG)
+                self.logger('allocating TCP/IP port %s for our X-Server' % _xserver_port, loglevel=log.loglevel_DEBUG)
                 _detect_xserver_port = _xserver_port
 
             # if the port changed, let's write it to our configuration file
             if _detect_xserver_port != _last_xserver_port:
                 _new_display = _last_display.replace(str(_last_xserver_port -6000), str(_detect_xserver_port -6000))
-                self.logger('cannot used configured X DISPLAY, the new available DISPLAY port %s has been detected' % _new_display, loglevel=log.loglevel_NOTICE)
+                self.logger('cannot use configured X DISPLAY, the new available DISPLAY port %s has been detected' % _new_display, loglevel=log.loglevel_NOTICE)
                 self.update_value(xserver_name, 'last_display', _new_display)
                 _parameters = self.get_value(xserver_name, 'parameters')
                 _parameters[0] = ":%s" % (_detect_xserver_port -6000)
                 self.update_value(xserver_name, 'parameters', tuple(_parameters))  
                 self.write_user_config = True
                 self.write()
+                return _new_display
+
+            return _last_display
 
         except TypeError:
             pass
